@@ -710,7 +710,7 @@ class RelationshipGuid(base.QueryableModel):
     path = 'relationship/guid'
     data_key = 'relationship_guid'
     primary_key = 'guid'
-    fields = ('guid', 'status', 'createdBy',
+    fields = ('guid', 'status', 'createdBy', 'referredEntities', 'relationship',
               'updatedBy', 'createTime', 'updateTime',
               'version', 'end1', 'end2', 'label', 'typeName', 'attributes')
 
@@ -759,6 +759,9 @@ class Relationship(base.QueryableModel):
               'updatedBy', 'createTime', 'updateTime',
               'version', 'end1', 'end2', 'label', 'typeName', 'attributes')
 
+    def _generate_input_dict(self, **kwargs):
+        return kwargs.get("data")
+
     @events.evented
     def update(self, **kwargs):
         """Update a resource by passing in modifications via keyword arguments.
